import os
from cleo import Command


class InitCommand(Command):
    """
    Initiatlize an MKTimeline project.

    init
        {dir? : initialize dir as an MKTimeline project}
        {--t|template=template.html : template to use for rending timeline during build. }
    """

    def handle(self):
        dir = os.getcwd()
        if self.argument("dir"):
            dir = self.argument("dir")
        if not self.confirm(
            """Create a timeline project in directory "{}"?""".format(dir), False
        ):
            return
        self.line(
            """<info>Initializing MKTimeline project in directory "{}".</info>""".format(
                dir
            )
        )

        from mktimeline.timeline import Project

        Project.init(dir, self.option("template"))




from cleo import Command
import json
from ...timeline import Project


class BuildCommand(Command):
    """
    Render timeline project to output directory using the specified template.

    build
        {file? : File to write the timeline to.}
        {--stdout : Write to standard output instead of file.}    
    """

    def handle(self):
        output = self.argument("file")
        self.line("""<info>Outputing timeline to {}.</info>""".format(output))

        project = Project()
        render = project.export2html()

        if self.option("stdout"):
            self.line("""<info>Export to stdout</info>""")
            print(render)
        elif not output:
            self.line("""<error>You must specify an output file or --stdout</>""")
            return 1
        else:
            self.line("""<info>Export to {}</>""".format(output))
            with open(output, "w") as outfile:
                outfile.write(render)




from cleo import Command


class AboutCommand(Command):

    name = "about"

    description = "Shows information about mktimeline."

    def handle(self):
        self.line(
            """<info>MKTimeline - timeline creator, static site generator for timelines</info>
<comment>MKTimeline is a static site generator for creating timelines. 
See <fg=blue>https://github.com/jduprey/mktimeline</> for more information.</comment>"""
        )



import json

import markdown
from bs4 import BeautifulSoup
from frontmatter import Frontmatter

CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])


class Event:
    mdfile = ""

    def __init__(self, mdfile):
        self.mdfile = mdfile

    def md2json(self):
        """
        Transforms a markdown file with yaml frontmatter to a timeline event in JSON format
        """
        event = self.to_event()

        return json.dumps(event, indent=4)

    def get_inner_html(self, elt):
        if not elt:
            return ""

        return "".join([str(x) for x in elt.contents])

    def to_event(self):
        with open(self.mdfile, encoding="utf-8-sig") as f:
            post = Frontmatter.read(f.read())
        if len(post["body"]) == 0 or len(post["frontmatter"]) == 0:
            raise Exception("Error reading {} or incorrect format.".format(self.mdfile))

        soup = BeautifulSoup(markdown.markdown(post["body"]), "html.parser")

        first_element = soup.find()
        try:
            if first_element.name != "h1":
                raise Exception(
                    'Expected first element to be an "H1" instead it was {}'.format(
                        first_element.name
                    )
                )
        except Exception as e:
            raise Exception(
                "Failed to parse heading from first element: {}".format(first_element),
                e,
            )

        first_element.extract()
        event = post["attributes"]
        caption_elt = BeautifulSoup(
            markdown.markdown(event["media"]["caption"]), "html.parser"
        )
        credit_elt = BeautifulSoup(
            markdown.markdown(event["media"]["credit"]), "html.parser"
        )
        event["media"]["caption"] = self.get_inner_html(caption_elt.p)
        event["media"]["credit"] = self.get_inner_html(credit_elt.p)
        event["text"] = {"headline": first_element.text, "text": str(soup)}
        return event



import json
from pathlib import Path
from collections import defaultdict

from bin.mdevent2json import to_event

title = to_event('etc/timeline/title.md')

events = []
for filename in Path('etc/timeline/events').glob('**/*.md'):
    event = to_event(filename)
    if event:
        events.append(event)

for event in events:
    if 'month' in event['start_date']:
        event['start_date']['month'] = event['start_date']['month'].rjust(2, '0')
    if 'day' in event['start_date']:
        event['start_date']['month'] = event['start_date']['day'].rjust(2, '0')

# Make sure events are sorted by start date
events.sort(
    key=lambda event: "{0[year]}-{0[month]}-{0[day]}".format(
        defaultdict(str, **(event['start_date']))), reverse=False)

timeline = {'title': title, 'events': events}
print(json.dumps(timeline, indent=4))



import json
import os.path
import re
from collections import defaultdict
from os import makedirs

import yaml

with open('etc/timeline.json') as tljsonf:
    timeline = json.load(tljsonf)
    title = timeline['title']
    title_text = title.pop('text')

    # Write the Title Markdown File
    yaml_text = "---\n"
    yaml_text += yaml.dump(title, default_flow_style=False)
    yaml_text += "---\n\n"
    yaml_text += "# {} \n\n {}".format(title_text['headline'], title_text['text'])

    filename = "title.md"
    filelocation = os.path.join('etc/timeline', filename)

    with open(filelocation, 'w') as yf:
        yf.write(yaml_text)

    for event in timeline['events']:
        # Write the Title Markdown File
        event_text = event.pop('text')
        yaml_text = "---\n"
        media = event
        yaml_text += yaml.dump(media, default_flow_style=False)
        yaml_text += "---\n\n"
        yaml_text += "# {} \n\n {}".format(
            event_text['headline'], event_text['text'])

        date_prefix = "{0[year]}-{0[month]}-{0[day]}".format(
            defaultdict(str, **(event['start_date'])))
        filename_base = "{}_{}".format(date_prefix, re.sub(
            r'\W+', '_', event_text['headline'].lower()))
        filedir = os.path.join('etc/timeline/events/', filename_base)
        makedirs(filedir, exist_ok=True)
        makedirs(os.path.join(filedir, 'assets'), exist_ok=True)
        filelocation = os.path.join(filedir, "{}.md".format(filename_base))
        with open(filelocation, 'w') as yf:
            yf.write(yaml_text)



import json
import csv
import re
from jinja2 import Environment, FileSystemLoader, select_autoescape
from collections import defaultdict

env = Environment(
    loader=FileSystemLoader("etc/templates"),
    autoescape=select_autoescape(["html", "xml"]),
)

# with open('/Users/jduprey/Source/c3-rdp2/src/assets/org.csv') as orgcsvf:
with open("/Users/jduprey/Downloads/org.csv") as orgcsvf:
    csv_reader = csv.DictReader(orgcsvf, delimiter=",")
    sortedlist = sorted(csv_reader, key=lambda row: (row["name"]), reverse=False)

    anchors = []
    anchor = ""
    for row in sortedlist:
        if anchor != row["name"][0].upper():
            anchor = row["name"][0].upper()
            anchors.append(anchor)

    locations = {}
    for row in sortedlist:
        location = row["location"]
        if location not in locations:
            locations[location] = 0
        locations[location] += 1
        row["bio"] = re.sub("^<span.*Biography</span>", "", row["bio"])
        # row['bio'] = """
        # Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
        # """

    # Generate the HTML from the template
    template = env.get_template("meet-the-team.html")
    print(
        template.render(
            {
                "rows": sortedlist,
                "anchors": anchors,
                "num_locations": len(locations),
                "locations": locations,
            }
        )
    )



import json
from cleo import Command
from ...timeline import Project


class ExportTimelineCommand(Command):
    """
    Export timline project to Knightlab timeline JSON file format - https://timeline.knightlab.com/.

    export
        {jsonfile? : JSON file to write to.}
        {--stdout : Write to standard output instead of file.}    
    """

    def handle(self):
        jsonfile = self.argument("jsonfile")

        project = Project()
        timeline = project.export()

        if self.option("stdout"):
            self.line("""<info>Export to stdout</info>""")
            print(json.dumps(timeline, indent=4))
        elif not jsonfile:
            self.line("""<error>you must specify an output file or --stdout</>""")
            return 1
        else:
            self.line("""<info>Export to {}</>""".format(jsonfile))
            with open(jsonfile, "w") as outfile:
                print(json.dump(timeline, outfile, indent=4))




from .commands import AboutCommand
from .commands import ImportTimelineCommand
from .commands import ExportTimelineCommand
from .commands import BuildCommand
from .commands import InitCommand
from cleo import Application


def main():
    application = Application()
    application.add(AboutCommand())
    application.add(ImportTimelineCommand())
    application.add(ExportTimelineCommand())
    application.add(BuildCommand())
    application.add(InitCommand())
    application.run()


if __name__ == "__main__":
    main()



import json
import re
from jinja2 import Environment, FileSystemLoader, select_autoescape
from collections import defaultdict

env = Environment(
    loader=FileSystemLoader('etc/templates'),
    autoescape=select_autoescape(['html', 'xml'])
)

with open('etc/timeline.json') as tljsonf:
    timeline = json.load(tljsonf)

    # Fix title media
    if timeline['title']['media']['url'].find('//youtu') != -1:
        timeline['title']['media']['url'] = re.sub(
            r".*\/(.*)$", r'https://youtube.com/embed/\1?rel=0', timeline['title']['media']['url'])

    # Make sure events are sorted by start date
    events = timeline['events'].sort(
        key=lambda event: "{0[year]}-{0[month]}-{0[day]}".format(
            defaultdict(str, **(event['start_date']))), reverse=False)

    # Convert media youtube URLs to embed urls...
    for event in timeline['events']:
        if 'media' in event and 'url' in event['media'] and event['media']['url'].find('//youtu') != -1:
            event['media']['url'] = re.sub(
                r".*\/(.*)$", r'https://youtube.com/embed/\1?rel=0', event['media']['url'])

    # Generate the HTML from the template
    template = env.get_template('non-interactive.html')
    print(template.render(timeline))



import json
import shutil
import yaml
import os
import re
from collections import defaultdict
from pathlib import Path

from jinja2 import Environment, FileSystemLoader, PackageLoader, select_autoescape

import importlib.resources as pkg_resources

from .. import templates

from ..events import Event

# https://stackoverflow.com/questions/6028000/how-to-read-a-static-file-from-inside-a-python-package
# https://docs.python.org/3.8/library/importlib.html?highlight=importlib#module-importlib.resources
# for i in pkg_resources.contents(templates):
#     print(i)

# template_path = pkg_resources.path(templates, ".")
# print("PATH: {}".format(template_path))

project_fname = "timeline_project.yml"

title_template = """---
media:
  caption: {media[caption]}
  credit: {media[credit]}
  url: {media[url]}
---

# {heading}

{description}
"""


class Project:
    """
    Timeline Project
    """

    project_data = {}
    project_dir = os.getcwd()
    events_dir = os.path.join(project_dir, "events")
    project_file = os.path.join(project_dir, project_fname)
    timeline = {}

    def __init__(self):
        if not os.path.exists(self.project_file):
            raise Exception("Missing project data.")

        with open(self.project_file) as r:
            self.project_data = yaml.load(r)

        self.timeline = self.export()

    @staticmethod
    def init(project_dir, template):
        title_data = {
            "heading": "HEADLINE",
            "description": "DESCRIPTION",
            "media": {"caption": "CAPTION", "credit": "CREDIT", "url": "URL"},
        }

        data = {"template": template, "templates_dir": "templates"}

        if not os.path.exists(project_dir):
            os.makedirs(project_dir)

        if os.path.exists(os.path.join(project_dir, project_fname)):
            print("Project file already exists.")
        else:
            with open(os.path.join(project_dir, project_fname), "w") as f:
                yaml.dump(data, f, default_flow_style=False)

        events_dir = os.path.join(project_dir, "events")
        if os.path.exists(events_dir):
            print("Project events directory already exists.")
        else:
            os.makedirs(events_dir)

        with open(os.path.join(project_dir, "title.md"), "w") as f:
            f.write(title_template.format(**title_data))

        shutil.copytree(
            templates.__path__[0],
            os.path.join(project_dir, data["templates_dir"]),
            ignore=shutil.ignore_patterns("*.py", "*.pyc", "__py*"),
        )

    def export(self):
        ev = Event("title.md")
        title = ev.to_event()

        events = []
        for filename in Path("events").glob("**/*.md"):
            ev = Event(filename)
            if ev:
                events.append(ev.to_event())

        for ev in events:
            if "month" in ev["start_date"]:
                ev["start_date"]["month"] = ev["start_date"]["month"].rjust(2, "0")
            if "day" in ev["start_date"]:
                ev["start_date"]["month"] = ev["start_date"]["day"].rjust(2, "0")

        # Make sure events are sorted by start date
        events.sort(
            key=lambda event: "{0[year]}-{0[month]}-{0[day]}".format(
                defaultdict(str, **(ev["start_date"]))
            ),
            reverse=False,
        )

        timeline = {"title": title, "events": events}
        return timeline

    def export2html(self):
        # Fix title media
        if self.timeline["title"]["media"]["url"].find("//youtu") != -1:
            self.timeline["title"]["media"]["url"] = re.sub(
                r".*\/(.*)$",
                r"https://youtube.com/embed/\1?rel=0",
                self.timeline["title"]["media"]["url"],
            )

        # Make sure events are sorted by start date
        self.timeline["events"].sort(
            key=lambda event: "{0[year]}-{0[month]}-{0[day]}".format(
                defaultdict(str, **(event["start_date"]))
            ),
            reverse=False,
        )

        # Convert media youtube URLs to embed urls...
        for ev in self.timeline["events"]:
            if (
                "media" in ev
                and "url" in ev["media"]
                and ev["media"]["url"].find("//youtu") != -1
            ):
                ev["media"]["url"] = re.sub(
                    r".*\/(.*)$",
                    r"https://youtube.com/embed/\1?rel=0",
                    ev["media"]["url"],
                )

        env = Environment(
            # loader=PackageLoader("mktimeline", "templates"),
            loader=FileSystemLoader(self.project_data["templates_dir"]),
            autoescape=select_autoescape(["html", "xml"]),
        )

        # Generate the HTML from the template
        template = env.get_template(self.project_data["template"])
        return template.render(self.timeline)



import yaml
import json
from collections import defaultdict

with open('etc/timeline.yml') as tlyamlf:
    timeline = yaml.load(tlyamlf)

    for event in timeline['events']:
        if 'month' in event['start_date']:
            event['start_date']['month'] = event['start_date']['month'].rjust(2, '0')
        if 'day' in event['start_date']:
            event['start_date']['month'] = event['start_date']['day'].rjust(2, '0')

    # Make sure events are sorted by start date
    events = timeline['events'].sort(
        key=lambda event: "{0[year]}-{0[month]}-{0[day]}".format(
            defaultdict(str, **(event['start_date']))), reverse=False)
    print(json.dumps(timeline, indent=4))



from cleo import Command


class ImportTimelineCommand(Command):
    """
    Import timline from Knightlab timeline JSON file format - https://timeline.knightlab.com/.

    import
        {jsonfile : JSON file that follows Knightlab timeline JSON file format - https://timeline.knightlab.com/}    
    """

    def handle(self):
        jsonfile = self.argument("jsonfile")
        self.line("""<info>Import from {}</info>""".format(jsonfile))




# -*- coding: utf-8 -*-
from distutils.core import setup

package_dir = \
{'': 'src'}

packages = \
['mktimeline',
 'mktimeline.console',
 'mktimeline.console.commands',
 'mktimeline.events',
 'mktimeline.templates',
 'mktimeline.timeline']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2',
 'cleo>=0.7.5,<0.8.0',
 'frontmatter>=3.0,<4.0',
 'jinja2>=2.10,<3.0',
 'markdown>=3.1,<4.0']

entry_points = \
{'console_scripts': ['mktimeline = mktimeline.console.application:main']}

setup_kwargs = {
    'name': 'mktimeline',
    'version': '0.1.0',
    'description': '',
    'long_description': '# mktimeline - a timeline tool\nA tool for creating interactive/visual timelines.\n',
    'author': 'John Duprey',
    'author_email': '297628+jduprey@users.noreply.github.com',
    'url': 'https://www.iduprey.com/',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import json

import click
import markdown
from bs4 import BeautifulSoup
from frontmatter import Frontmatter

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])


@click.group(context_settings=CONTEXT_SETTINGS)
@click.version_option(version='1.0.0')
def greet():
    pass


@greet.command()
@click.argument('mdfile', default='etc/event_template.md', required=True, type=click.Path(exists=True))
@click.option('--greeting', default='Hello', help='word to use for the greeting')
@click.option('--caps', is_flag=True, help='uppercase the output')
def md2json(**kwargs):
    """
    Transforms a markdown file with yaml frontmatter to a timeline event in JSON format
    """
    mdfile = kwargs['mdfile']
    event = to_event(mdfile)

    print(json.dumps(event, indent=4))


def get_inner_html(elt):
    if not elt:
        return ''

    return "".join([str(x) for x in elt.contents])


def to_event(mdfile):
    with open(mdfile, encoding='utf-8-sig') as f:
        post = Frontmatter.read(f.read())
    if len(post['body']) == 0 or len(post['frontmatter']) == 0:
        raise Exception("Error reading {} or incorrect format.".format(mdfile))

    soup = BeautifulSoup(markdown.markdown(post['body']), 'html.parser')

    first_element = soup.find()
    try:
        if first_element.name != 'h1':
            raise Exception(
                'Expected first element to be an "H1" instead it was {}'.format(first_element.name))
    except Exception as e:
        raise Exception(
            "Failed to parse heading from first element: {}".format(first_element), e)

    first_element.extract()
    event = post['attributes']
    caption_elt = BeautifulSoup(markdown.markdown(
        event['media']['caption']), 'html.parser')
    credit_elt = BeautifulSoup(markdown.markdown(
        event['media']['credit']), 'html.parser')
    event['media']['caption'] = get_inner_html(caption_elt.p)
    event['media']['credit'] = get_inner_html(credit_elt.p)
    event['text'] = {'headline': first_element.text,
                     'text': str(soup)}
    return event


if __name__ == '__main__':
    greet()
